@@ -11,7 +11,7 @@ our $VERSION;
 # $VERSION declaration must stay up here, ahead of any other package
 # declarations, as to not confuse various modules attempting to determine
 # this ones version, whether that be s.c.o. or Module::Metadata, etc
-$VERSION = '0.08209';
+$VERSION = '0.08210';
 
 $VERSION = eval $VERSION if $VERSION =~ /_/; # numify for warning-free dev releases
 
@@ -95,53 +95,51 @@ sub _attr_cache {
 
 1;
 
+__END__
+
+=encoding UTF-8
+
 =head1 NAME
 
 DBIx::Class - Extensible and flexible object <-> relational mapper.
 
-=head1 GETTING HELP/SUPPORT
+=head1 WHERE TO START READING
 
-The community can be found via:
+See L<DBIx::Class::Manual::DocMap> for an overview of the exhaustive documentation.
+To get the most out of DBIx::Class with the least confusion it is strongly
+recommended to read (at the very least) the
+L<Manuals|DBIx::Class::Manual::DocMap/Manuals> in the order presented there.
+
+=head1 HOW TO GET HELP
+
+Due to the complexity of its problem domain, DBIx::Class is a relatively
+complex framework. After you start using DBIx::Class questions will inevitably
+arise. If you are stuck with a problem or have doubts about a particular
+approach do not hesitate to contact the community with your questions. The
+list below is sorted by "fastest response time":
 
 =over
 
 =item * IRC: irc.perl.org#dbix-class
 
 =for html
-<a href="http://chat.mibbit.com/#dbix-class@irc.perl.org">(click for instant chatroom login)</a>
+<a href="https://chat.mibbit.com/#dbix-class@irc.perl.org">(click for instant chatroom login)</a>
 
 =item * Mailing list: L<http://lists.scsys.co.uk/mailman/listinfo/dbix-class>
 
-=item * Twitter L<http://www.twitter.com/dbix_class>
+=item * RT Bug Tracker: L<https://rt.cpan.org/NoAuth/Bugs.html?Dist=DBIx-Class>
+
+=item * Twitter: L<https://www.twitter.com/dbix_class>
 
 =item * Web Site: L<http://www.dbix-class.org/>
 
-=item * RT Bug Tracker: L<https://rt.cpan.org/Dist/Display.html?Queue=DBIx-Class>
-
-=back
-
-The project is maintained in a git repository, accessible from the following sources:
-
-=over
-
-=item * git: L<git://git.shadowcat.co.uk/dbsrgits/DBIx-Class.git>
-
-=item * gitweb: L<http://git.shadowcat.co.uk/gitweb/gitweb.cgi?p=dbsrgits/DBIx-Class.git>
-
-=item * github mirror: L<https://github.com/dbsrgits/DBIx-Class>
-
-=item * authorized committers: L<ssh://dbsrgits@git.shadowcat.co.uk/DBIx-Class.git>
-
-=item * Travis-CI log: L<http://travis-ci.org/dbsrgits/dbix-class/builds>
-
-=for html
-<img src="https://secure.travis-ci.org/dbsrgits/dbix-class.png?branch=master"></img>
-
 =back
 
 =head1 SYNOPSIS
 
-Create a schema class called MyApp/Schema.pm:
+=head2 Schema classes preparation
+
+Create a schema class called F<MyApp/Schema.pm>:
 
   package MyApp::Schema;
   use base qw/DBIx::Class::Schema/;
@@ -151,7 +149,7 @@ Create a schema class called MyApp/Schema.pm:
   1;
 
 Create a result class to represent artists, who have many CDs, in
-MyApp/Schema/Result/Artist.pm:
+F<MyApp/Schema/Result/Artist.pm>:
 
 See L<DBIx::Class::ResultSource> for docs on defining result classes.
 
@@ -166,7 +164,7 @@ See L<DBIx::Class::ResultSource> for docs on defining result classes.
   1;
 
 A result class to represent a CD, which belongs to an artist, in
-MyApp/Schema/Result/CD.pm:
+F<MyApp/Schema/Result/CD.pm>:
 
   package MyApp::Schema::Result::CD;
   use base qw/DBIx::Class::Core/;
@@ -179,6 +177,8 @@ MyApp/Schema/Result/CD.pm:
 
   1;
 
+=head2 API usage
+
 Then you can use these classes in your application's code:
 
   # Connect to your database.
@@ -247,7 +247,8 @@ that allows abstract encapsulation of database operations. It aims to make
 representing queries in your code as perl-ish as possible while still
 providing access to as many of the capabilities of the database as possible,
 including retrieving related records from multiple tables in a single query,
-JOIN, LEFT JOIN, COUNT, DISTINCT, GROUP BY, ORDER BY and HAVING support.
+C<JOIN>, C<LEFT JOIN>, C<COUNT>, C<DISTINCT>, C<GROUP BY>, C<ORDER BY> and
+C<HAVING> support.
 
 DBIx::Class can handle multi-column primary and foreign keys, complex
 queries and database-level paging, and does its best to only query the
@@ -260,8 +261,8 @@ and thread-safe out of the box (although
 L<your DBD may not be|DBI/Threads and Thread Safety>).
 
 This project is still under rapid development, so large new features may be
-marked EXPERIMENTAL - such APIs are still usable but may have edge bugs.
-Failing test cases are *always* welcome and point releases are put out rapidly
+marked B<experimental> - such APIs are still usable but may have edge bugs.
+Failing test cases are I<always> welcome and point releases are put out rapidly
 as bugs are found and fixed.
 
 We do our best to maintain full backwards compatibility for published
@@ -273,10 +274,37 @@ The test suite is quite substantial, and several developer releases
 are generally made to CPAN before the branch for the next release is
 merged back to trunk for a major release.
 
-=head1 WHERE TO GO NEXT
+=head1 HOW TO CONTRIBUTE
 
-L<DBIx::Class::Manual::DocMap> lists each task you might want help on, and
-the modules where you will find documentation.
+Contributions are always welcome, in all usable forms (we especially
+welcome documentation improvements). The delivery methods include git-
+or unified-diff formatted patches, GitHub pull requests, or plain bug
+reports either via RT or the Mailing list. Contributors are generally
+granted full access to the official repository after their first patch
+passes successful review.
+
+=for comment
+FIXME: Getty, frew and jnap need to get off their asses and finish the contrib section so we can link it here ;)
+
+This project is maintained in a git repository. The code and related tools are
+accessible at the following locations:
+
+=over
+
+=item * Official repo: L<git://git.shadowcat.co.uk/dbsrgits/DBIx-Class.git>
+
+=item * Official gitweb: L<http://git.shadowcat.co.uk/gitweb/gitweb.cgi?p=dbsrgits/DBIx-Class.git>
+
+=item * GitHub mirror: L<https://github.com/dbsrgits/DBIx-Class>
+
+=item * Authorized committers: L<ssh://dbsrgits@git.shadowcat.co.uk/DBIx-Class.git>
+
+=item * Travis-CI log: L<https://travis-ci.org/dbsrgits/dbix-class/builds>
+
+=for html
+&#x21AA; Stable branch CI status: <img src="https://secure.travis-ci.org/dbsrgits/dbix-class.png?branch=master"></img>
+
+=back
 
 =head1 AUTHOR
 
@@ -343,8 +371,12 @@ clkao: CL Kao
 
 da5id: David Jack Olrik <djo@cpan.org>
 
+dariusj: Darius Jokilehto <dariusjokilehto@yahoo.co.uk>
+
 davewood: David Schmidt <davewood@gmx.at>
 
+daxim: Lars Dɪᴇᴄᴋᴏᴡ 迪拉斯 <daxim@cpan.org>
+
 debolaz: Anders Nor Berle <berle@cpan.org>
 
 dew: Dan Thomas <dan@godders.org>
@@ -423,6 +455,8 @@ michaelr: Michael Reddick <michael.reddick@gmail.com>
 
 milki: Jonathan Chu <milki@rescomp.berkeley.edu>
 
+mithaldu: Christian Walde <walde.christian@gmail.com>
+
 mjemmeson: Michael Jemmeson <michael.jemmeson@gmail.com>
 
 mstratman: Mark A. Stratman <stratman@gmail.com>
@@ -542,5 +576,3 @@ as listed above.
 
 This library is free software and may be distributed under the same terms
 as perl itself.
-
-=cut
