@@ -4,6 +4,7 @@ use strict;
 use warnings;
 
 use DBIx::Class::Carp ();
+$Carp::Internal{ (__PACKAGE__) }++;
 
 use overload
     '""' => sub { shift->{msg} },
@@ -83,9 +84,9 @@ sub rethrow {
     die shift;
 }
 
-=head1 AUTHORS
+=head1 AUTHOR AND CONTRIBUTORS
 
-Brandon L. Black <blblack@gmail.com>
+See L<AUTHOR|DBIx::Class/AUTHOR> and L<CONTRIBUTORS|DBIx::Class/CONTRIBUTORS> in DBIx::Class
 
 =head1 LICENSE
 
